/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_E1m03V6U, &hTable_BqJ719EO);
  numBytes += sTabread_init(&sTabread_OJabLwRp, &hTable_BqJ719EO, true);
  numBytes += sRPole_init(&sRPole_LKtoqDDL);
  numBytes += sEnv_init(&sEnv_YGNIG7Yk, 1024, 512);
  numBytes += sLine_init(&sLine_v8wsnSTc);
  numBytes += cSlice_init(&cSlice_RFtvNK5g, 1, -1);
  numBytes += cSlice_init(&cSlice_vtf1Wxjy, 1, -1);
  numBytes += cVar_init_f(&cVar_GH74eCfD, 0.0f);
  numBytes += cIf_init(&cIf_alpnKi4J, false);
  numBytes += cBinop_init(&cBinop_CBllpU9Z, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_xQQFEhOg, 1, -1);
  numBytes += cSlice_init(&cSlice_6ceFydzd, 1, -1);
  numBytes += cVar_init_f(&cVar_riLSVUco, 0.0f);
  numBytes += cIf_init(&cIf_m6Ju8OoZ, false);
  numBytes += cBinop_init(&cBinop_6HDQVDWW, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_sgSqQd6Q, 0.0f);
  numBytes += cVar_init_f(&cVar_5XsSlVDh, 0.0f);
  numBytes += cBinop_init(&cBinop_GWZNzTYo, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_4gT8tdkT, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_oaN8UdZa, 2, 1);
  numBytes += cSlice_init(&cSlice_hqEH5Ox5, 1, 1);
  numBytes += cSlice_init(&cSlice_ltzaFLJr, 0, 1);
  numBytes += cVar_init_f(&cVar_yWP0RQ90, 0.0f);
  numBytes += cIf_init(&cIf_e9sjCvQB, false);
  numBytes += cIf_init(&cIf_DHdZOK3m, false);
  numBytes += cIf_init(&cIf_vYsJd13y, false);
  numBytes += cIf_init(&cIf_hCFjP6pJ, false);
  numBytes += cIf_init(&cIf_wV4F9PQQ, false);
  numBytes += cBinop_init(&cBinop_n9KXfjyJ, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_qDrddMgR, 10.0f);
  numBytes += cPack_init(&cPack_rIm8NvI9, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_P6PIE30V, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_GcFHGm7D, 10.0f);
  numBytes += cPack_init(&cPack_OGal2EGX, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_nFgK8DPH, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_XjAj76UU, 10.0f);
  numBytes += cPack_init(&cPack_EBY0s9nL, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_4qZSE2IG, 1e-07f);
  numBytes += cIf_init(&cIf_MPwbvObR, true);
  numBytes += cVar_init_f(&cVar_7PsICXrn, 1e-07f);
  numBytes += cVar_init_f(&cVar_s1da1DCc, 1e-07f);
  numBytes += sVarf_init(&sVarf_Qnb8xZNe, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Cd4mIpGB, 0.0f);
  numBytes += cVar_init_f(&cVar_bosorgcn, 20.0f);
  numBytes += cBinop_init(&cBinop_ZSkJ0C4Z, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_61N5KHIg, 0.0f);
  numBytes += cSlice_init(&cSlice_mVPuAm2c, 1, -1);
  numBytes += cSlice_init(&cSlice_JiwgUx0F, 1, -1);
  numBytes += cVar_init_f(&cVar_X3YwYYfB, 0.0f);
  numBytes += cVar_init_f(&cVar_ZtbNolyd, 20.0f);
  numBytes += cVar_init_f(&cVar_PVjgP8hK, 0.0f);
  numBytes += cVar_init_f(&cVar_C8mbn1FS, 0.0f);
  numBytes += cVar_init_f(&cVar_7xRs8B5M, 0.0f);
  numBytes += cSlice_init(&cSlice_ymzgoqBQ, 1, 1);
  numBytes += cSlice_init(&cSlice_RSmA7Hz3, 0, 1);
  numBytes += cBinop_init(&cBinop_h7CvpPwk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gzbHqWeM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_asg0N8Ag, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_sJMaCY4v, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_6km8wYHn, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_ZwgJD4tN, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_XVSoKJGh, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KBucz4w6, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_cwXvZ3LW, 5.0f);
  numBytes += cVar_init_f(&cVar_37RaWqAW, 500.0f);
  numBytes += cBinop_init(&cBinop_sO2JZudU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TTkUlP87, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xpc2mmQm, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_OHH476hj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WnWWN0WF, 0.0f);
  numBytes += hTable_init(&hTable_BqJ719EO, 256);
  numBytes += cTabhead_init(&cTabhead_niRFyR8n, &hTable_BqJ719EO);
  numBytes += cVar_init_s(&cVar_1atglzQe, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_cHBN195U, 8.0f);
  numBytes += cDelay_init(this, &cDelay_bUvYMwNU, 0.0f);
  numBytes += cBinop_init(&cBinop_dpKMKLB0, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_pGmDYQ1i, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ugCQNQ11, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_pMfo5gzU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_vNuH5SuF, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_knpUZ5Xi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JcN8nIkT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l4LmtVPk, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_YGNIG7Yk);
  cPack_free(&cPack_rIm8NvI9);
  cPack_free(&cPack_OGal2EGX);
  cPack_free(&cPack_EBY0s9nL);
  hTable_free(&hTable_BqJ719EO);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_BqJ719EO; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eYISdHG4_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OclijZ0v_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v6IV3d4n_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WA2qyrvp_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KUOd7PNM_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TKsyjdyM_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eVOpMJvz_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R5HiD4Wg_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jynxMxDp_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xYIEOyb8_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sTbpEukI_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ryqRU2Cg_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ppvKIxcj_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_knWwYRe0_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J58HdQG4_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oGaV55EG_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xKw5SApR_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_YGNIG7Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GWZNzTYo, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GWZNzTYo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4gT8tdkT, HV_BINOP_LESS_THAN, 0, m, &cBinop_4gT8tdkT_sendMessage);
}

void Heavy_vSwell::cSwitchcase_iBbC7JxZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RFtvNK5g, 0, m, &cSlice_RFtvNK5g_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vtf1Wxjy, 0, m, &cSlice_vtf1Wxjy_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Li34wdtB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gJW56z9G_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_RFtvNK5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_GH74eCfD, 0, m, &cVar_GH74eCfD_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GH74eCfD, 0, m, &cVar_GH74eCfD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_vtf1Wxjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CBllpU9Z, HV_BINOP_NEQ, 1, m, &cBinop_CBllpU9Z_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GH74eCfD, 1, m, &cVar_GH74eCfD_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CBllpU9Z, HV_BINOP_NEQ, 1, m, &cBinop_CBllpU9Z_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GH74eCfD, 1, m, &cVar_GH74eCfD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_GH74eCfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_873Idde6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_alpnKi4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gBCTqFVQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oQjEeApx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_gBCTqFVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CBllpU9Z, HV_BINOP_NEQ, 1, m, &cBinop_CBllpU9Z_sendMessage);
}

void Heavy_vSwell::cCast_oQjEeApx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GH74eCfD, 0, m, &cVar_GH74eCfD_sendMessage);
}

void Heavy_vSwell::cBinop_CBllpU9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_alpnKi4J, 1, m, &cIf_alpnKi4J_sendMessage);
}

void Heavy_vSwell::cCast_gJW56z9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_alpnKi4J, 0, m, &cIf_alpnKi4J_sendMessage);
}

void Heavy_vSwell::cCast_Li34wdtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CBllpU9Z, HV_BINOP_NEQ, 0, m, &cBinop_CBllpU9Z_sendMessage);
}

void Heavy_vSwell::cSwitchcase_w8pRQt5s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xQQFEhOg, 0, m, &cSlice_xQQFEhOg_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6ceFydzd, 0, m, &cSlice_6ceFydzd_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pcMQIMdF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YEcSJyUv_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_xQQFEhOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_riLSVUco, 0, m, &cVar_riLSVUco_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_riLSVUco, 0, m, &cVar_riLSVUco_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_6ceFydzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6HDQVDWW, HV_BINOP_NEQ, 1, m, &cBinop_6HDQVDWW_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_riLSVUco, 1, m, &cVar_riLSVUco_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6HDQVDWW, HV_BINOP_NEQ, 1, m, &cBinop_6HDQVDWW_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_riLSVUco, 1, m, &cVar_riLSVUco_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_riLSVUco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RkvB6BVg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_m6Ju8OoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sK6AOiT4_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9N7l3Tps_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_9N7l3Tps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_riLSVUco, 0, m, &cVar_riLSVUco_sendMessage);
}

void Heavy_vSwell::cCast_sK6AOiT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6HDQVDWW, HV_BINOP_NEQ, 1, m, &cBinop_6HDQVDWW_sendMessage);
}

void Heavy_vSwell::cBinop_6HDQVDWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m6Ju8OoZ, 1, m, &cIf_m6Ju8OoZ_sendMessage);
}

void Heavy_vSwell::cCast_YEcSJyUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m6Ju8OoZ, 0, m, &cIf_m6Ju8OoZ_sendMessage);
}

void Heavy_vSwell::cCast_pcMQIMdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6HDQVDWW, HV_BINOP_NEQ, 0, m, &cBinop_6HDQVDWW_sendMessage);
}

void Heavy_vSwell::cSwitchcase_873Idde6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xpcCWz3Z_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0h9bRCau_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_xpcCWz3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5XsSlVDh, 0, m, &cVar_5XsSlVDh_sendMessage);
}

void Heavy_vSwell::cCast_0h9bRCau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s7vReFsr_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MPwbvObR, 0, m, &cIf_MPwbvObR_sendMessage);
}

void Heavy_vSwell::cSwitchcase_RkvB6BVg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fnk05c19_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_09m5gsN7_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_fnk05c19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sgSqQd6Q, 0, m, &cVar_sgSqQd6Q_sendMessage);
}

void Heavy_vSwell::cCast_09m5gsN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6XBSfN4y_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_sgSqQd6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GWZNzTYo, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GWZNzTYo_sendMessage);
}

void Heavy_vSwell::cVar_5XsSlVDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4gT8tdkT, HV_BINOP_LESS_THAN, 1, m, &cBinop_4gT8tdkT_sendMessage);
}

void Heavy_vSwell::cBinop_GWZNzTYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iBbC7JxZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_4gT8tdkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w8pRQt5s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_s7vReFsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GWZNzTYo, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GWZNzTYo_sendMessage);
}

void Heavy_vSwell::cMsg_6XBSfN4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4gT8tdkT, HV_BINOP_LESS_THAN, 1, m, &cBinop_4gT8tdkT_sendMessage);
}

void Heavy_vSwell::cSlice_oaN8UdZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aLuayjHX_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_hqEH5Ox5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_hCFjP6pJ, 0, m, &cIf_hCFjP6pJ_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_DHdZOK3m, 0, m, &cIf_DHdZOK3m_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_ltzaFLJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_wV4F9PQQ, 0, m, &cIf_wV4F9PQQ_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_vYsJd13y, 0, m, &cIf_vYsJd13y_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_yWP0RQ90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zP51Ihv1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_e9sjCvQB, 0, m, &cIf_e9sjCvQB_sendMessage);
}

void Heavy_vSwell::cUnop_6VZXqUGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kxZ3x9I3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9KXfjyJ, HV_BINOP_EQ, 1, m, &cBinop_n9KXfjyJ_sendMessage);
}

void Heavy_vSwell::cUnop_zKgR99A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kxZ3x9I3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9KXfjyJ, HV_BINOP_EQ, 1, m, &cBinop_n9KXfjyJ_sendMessage);
}

void Heavy_vSwell::cIf_e9sjCvQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_zKgR99A0_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_6VZXqUGZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_zP51Ihv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e9sjCvQB, 1, m, &cIf_e9sjCvQB_sendMessage);
}

void Heavy_vSwell::cIf_DHdZOK3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Qd80KF6K_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_vYsJd13y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_hCFjP6pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Qd80KF6K_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_wV4F9PQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_aLuayjHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9KXfjyJ, HV_BINOP_EQ, 0, m, &cBinop_n9KXfjyJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_R3pRWzLa_sendMessage);
}

void Heavy_vSwell::cBinop_kxZ3x9I3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fFuztVnL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xZ0JZN7e_sendMessage);
}

void Heavy_vSwell::cBinop_n9KXfjyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9q8t1ZJx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v9cjTDgA_sendMessage);
}

void Heavy_vSwell::cCast_v9cjTDgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wV4F9PQQ, 1, m, &cIf_wV4F9PQQ_sendMessage);
}

void Heavy_vSwell::cCast_9q8t1ZJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DHdZOK3m, 1, m, &cIf_DHdZOK3m_sendMessage);
}

void Heavy_vSwell::cCast_fFuztVnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hCFjP6pJ, 1, m, &cIf_hCFjP6pJ_sendMessage);
}

void Heavy_vSwell::cCast_xZ0JZN7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vYsJd13y, 1, m, &cIf_vYsJd13y_sendMessage);
}

void Heavy_vSwell::cBinop_R3pRWzLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_yy6UVG1H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BZaWYpYT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BZaWYpYT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qDrddMgR, 1, m, &cDelay_qDrddMgR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xLglqOTd_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_qDrddMgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qDrddMgR, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWNTSTOa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nOHmW5gx_sendMessage);
  cSwitchcase_DtW9Hde7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_BZaWYpYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qDrddMgR, 0, m, &cDelay_qDrddMgR_sendMessage);
}

void Heavy_vSwell::cCast_xLglqOTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qDrddMgR, 0, m, &cDelay_qDrddMgR_sendMessage);
}

void Heavy_vSwell::cPack_rIm8NvI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y5qjEzff_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_P6PIE30V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oa6sR2yV_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_cshfHu6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_yy6UVG1H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_fQuDbcVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P6PIE30V, 0, m, &cVar_P6PIE30V_sendMessage);
}

void Heavy_vSwell::cCast_jrS6EuZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rIm8NvI9, 0, m, &cPack_rIm8NvI9_sendMessage);
}

void Heavy_vSwell::cMsg_Oa6sR2yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cMsg_Y5qjEzff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_DtW9Hde7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VIaST7Zh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VIaST7Zh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GcFHGm7D, 1, m, &cDelay_GcFHGm7D_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GQNAFcq1_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_GcFHGm7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GcFHGm7D, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cAeWIqAf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fMANy2rV_sendMessage);
  cSwitchcase_Z0q0jhYe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_VIaST7Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GcFHGm7D, 0, m, &cDelay_GcFHGm7D_sendMessage);
}

void Heavy_vSwell::cCast_GQNAFcq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GcFHGm7D, 0, m, &cDelay_GcFHGm7D_sendMessage);
}

void Heavy_vSwell::cPack_OGal2EGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bAhtcxQD_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_nFgK8DPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qhcuJsbA_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_vLsa7m6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_DtW9Hde7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_nOHmW5gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_OGal2EGX, 0, m, &cPack_OGal2EGX_sendMessage);
}

void Heavy_vSwell::cCast_vWNTSTOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nFgK8DPH, 0, m, &cVar_nFgK8DPH_sendMessage);
}

void Heavy_vSwell::cMsg_qhcuJsbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cMsg_bAhtcxQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_Z0q0jhYe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gMqZsbaI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gMqZsbaI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XjAj76UU, 1, m, &cDelay_XjAj76UU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eu2Z5OCr_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_XjAj76UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XjAj76UU, m);
}

void Heavy_vSwell::cMsg_gMqZsbaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XjAj76UU, 0, m, &cDelay_XjAj76UU_sendMessage);
}

void Heavy_vSwell::cCast_eu2Z5OCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XjAj76UU, 0, m, &cDelay_XjAj76UU_sendMessage);
}

void Heavy_vSwell::cPack_EBY0s9nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LRP20RpD_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_4qZSE2IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Ia6SRBg_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_Cy9NeG9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Z0q0jhYe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_cAeWIqAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4qZSE2IG, 0, m, &cVar_4qZSE2IG_sendMessage);
}

void Heavy_vSwell::cCast_fMANy2rV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EBY0s9nL, 0, m, &cPack_EBY0s9nL_sendMessage);
}

void Heavy_vSwell::cMsg_5Ia6SRBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cMsg_LRP20RpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cIf_MPwbvObR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TNa8dPeb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fa0Ius7A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_F8oFgzNe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wWWTDAf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_8wWWTDAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TNa8dPeb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fa0Ius7A_sendMessage);
}

void Heavy_vSwell::cVar_7PsICXrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p301BIIm_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_s1da1DCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EBY0s9nL, 1, m, &cPack_EBY0s9nL_sendMessage);
}

void Heavy_vSwell::cMsg_8S1X0KEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6nNH9OHw_sendMessage);
}

void Heavy_vSwell::cSystem_6nNH9OHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzbHqWeM, HV_BINOP_MULTIPLY, 1, m, &cBinop_gzbHqWeM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7CvpPwk, HV_BINOP_MULTIPLY, 1, m, &cBinop_h7CvpPwk_sendMessage);
}

void Heavy_vSwell::cSwitchcase_iG6TxRkf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cMsg_8wg6T0ft_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_8wg6T0ft_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sgEyuu47_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_Cd4mIpGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cd4mIpGB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cd4mIpGB, 0, m, &cDelay_Cd4mIpGB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_61N5KHIg, 0, m, &cVar_61N5KHIg_sendMessage);
}

void Heavy_vSwell::cCast_sgEyuu47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8wg6T0ft_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cd4mIpGB, 0, m, &cDelay_Cd4mIpGB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_61N5KHIg, 0, m, &cVar_61N5KHIg_sendMessage);
}

void Heavy_vSwell::cMsg_EEN4aqZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kcYq1vAd_sendMessage);
}

void Heavy_vSwell::cSystem_kcYq1vAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_x1Oco5QW_sendMessage);
}

void Heavy_vSwell::cVar_bosorgcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSkJ0C4Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZSkJ0C4Z_sendMessage);
}

void Heavy_vSwell::cMsg_8wg6T0ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cd4mIpGB, 0, m, &cDelay_Cd4mIpGB_sendMessage);
}

void Heavy_vSwell::cBinop_tOtOhCUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cd4mIpGB, 2, m, &cDelay_Cd4mIpGB_sendMessage);
}

void Heavy_vSwell::cBinop_x1Oco5QW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSkJ0C4Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZSkJ0C4Z_sendMessage);
}

void Heavy_vSwell::cBinop_ZSkJ0C4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_tOtOhCUy_sendMessage);
}

void Heavy_vSwell::cVar_61N5KHIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_asg0N8Ag, HV_BINOP_SUBTRACT, 0, m, &cBinop_asg0N8Ag_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_HCFeyogs_sendMessage);
}

void Heavy_vSwell::cSwitchcase_F0xr9PQ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gfxt4gzZ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_12fhLqXR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_Gfxt4gzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xRs8B5M, 0, m, &cVar_7xRs8B5M_sendMessage);
}

void Heavy_vSwell::cCast_12fhLqXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ukyIJvXG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FLpdKo7U_sendMessage);
}

void Heavy_vSwell::cSwitchcase_fE1t0vsd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mVPuAm2c, 0, m, &cSlice_mVPuAm2c_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JiwgUx0F, 0, m, &cSlice_JiwgUx0F_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ghn8mI6V_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_ymzgoqBQ, 0, m, &cSlice_ymzgoqBQ_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_RSmA7Hz3, 0, m, &cSlice_RSmA7Hz3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RNmAvzaJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IAPcwKNI_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_mVPuAm2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_yDIa8xeI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_yDIa8xeI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_JiwgUx0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QKP763EY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NaNynuUq_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QKP763EY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NaNynuUq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_X3YwYYfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pUMjh59h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sptpdylc_sendMessage);
}

void Heavy_vSwell::cVar_ZtbNolyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_q9VcoOOJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_q9VcoOOJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zhcyZEpA_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gzbHqWeM, HV_BINOP_MULTIPLY, 0, m, &cBinop_gzbHqWeM_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_6km8wYHn, HV_BINOP_DIVIDE, 1, m, &cBinop_6km8wYHn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_bosorgcn, 0, m, &cVar_bosorgcn_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_zhcyZEpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fecEVhxy_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_PVjgP8hK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBucz4w6, HV_BINOP_SUBTRACT, 1, m, &cBinop_KBucz4w6_sendMessage);
}

void Heavy_vSwell::cVar_C8mbn1FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xRs8B5M, 0, m, &cVar_7xRs8B5M_sendMessage);
}

void Heavy_vSwell::cVar_7xRs8B5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJMaCY4v, HV_BINOP_ADD, 0, m, &cBinop_sJMaCY4v_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVSoKJGh, HV_BINOP_ADD, 0, m, &cBinop_XVSoKJGh_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qnb8xZNe, m);
}

void Heavy_vSwell::cSlice_ymzgoqBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pUMjh59h_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sptpdylc_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_RSmA7Hz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_41KGe7im_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1IZlQg0_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_FWT4pnie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_61N5KHIg, 1, m, &cVar_61N5KHIg_sendMessage);
}

void Heavy_vSwell::cBinop_h7CvpPwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FWT4pnie_sendMessage);
}

void Heavy_vSwell::cBinop_gzbHqWeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZqLtYoSW_sendMessage);
}

void Heavy_vSwell::cBinop_ZqLtYoSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_asg0N8Ag, HV_BINOP_SUBTRACT, 1, m, &cBinop_asg0N8Ag_sendMessage);
}

void Heavy_vSwell::cBinop_asg0N8Ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_61N5KHIg, 1, m, &cVar_61N5KHIg_sendMessage);
}

void Heavy_vSwell::cMsg_0BRJb1Iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_iG6TxRkf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_Rh4Wz2h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_iG6TxRkf_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVSoKJGh, HV_BINOP_ADD, 1, m, &cBinop_XVSoKJGh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJMaCY4v, HV_BINOP_ADD, 1, m, &cBinop_sJMaCY4v_sendMessage);
}

void Heavy_vSwell::cBinop_HCFeyogs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F0xr9PQ0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_sJMaCY4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xRs8B5M, 1, m, &cVar_7xRs8B5M_sendMessage);
}

void Heavy_vSwell::cBinop_6km8wYHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZwgJD4tN, HV_BINOP_DIVIDE, 1, m, &cBinop_ZwgJD4tN_sendMessage);
}

void Heavy_vSwell::cBinop_ZwgJD4tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVSoKJGh, HV_BINOP_ADD, 1, m, &cBinop_XVSoKJGh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJMaCY4v, HV_BINOP_ADD, 1, m, &cBinop_sJMaCY4v_sendMessage);
}

void Heavy_vSwell::cCast_sptpdylc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6km8wYHn, HV_BINOP_DIVIDE, 0, m, &cBinop_6km8wYHn_sendMessage);
}

void Heavy_vSwell::cCast_pUMjh59h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7CvpPwk, HV_BINOP_MULTIPLY, 0, m, &cBinop_h7CvpPwk_sendMessage);
}

void Heavy_vSwell::cCast_41KGe7im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C8mbn1FS, 1, m, &cVar_C8mbn1FS_sendMessage);
}

void Heavy_vSwell::cCast_z1IZlQg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBucz4w6, HV_BINOP_SUBTRACT, 0, m, &cBinop_KBucz4w6_sendMessage);
}

void Heavy_vSwell::cCast_ukyIJvXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rh4Wz2h9_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_FLpdKo7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C8mbn1FS, 0, m, &cVar_C8mbn1FS_sendMessage);
}

void Heavy_vSwell::cBinop_XVSoKJGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PVjgP8hK, 0, m, &cVar_PVjgP8hK_sendMessage);
}

void Heavy_vSwell::cMsg_yDIa8xeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_iG6TxRkf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_6piFYbK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_X3YwYYfB, 1, m, &cVar_X3YwYYfB_sendMessage);
}

void Heavy_vSwell::cMsg_fecEVhxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzbHqWeM, HV_BINOP_MULTIPLY, 0, m, &cBinop_gzbHqWeM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6km8wYHn, HV_BINOP_DIVIDE, 1, m, &cBinop_6km8wYHn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bosorgcn, 0, m, &cVar_bosorgcn_sendMessage);
}

void Heavy_vSwell::cCast_NaNynuUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OXePGfJw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVSoKJGh, HV_BINOP_ADD, 0, m, &cBinop_XVSoKJGh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7xRs8B5M, 1, m, &cVar_7xRs8B5M_sendMessage);
}

void Heavy_vSwell::cCast_QKP763EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yDIa8xeI_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_KBucz4w6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZwgJD4tN, HV_BINOP_DIVIDE, 0, m, &cBinop_ZwgJD4tN_sendMessage);
}

void Heavy_vSwell::cCast_OXePGfJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rh4Wz2h9_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_IAPcwKNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6piFYbK1_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_Ghn8mI6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X3YwYYfB, 0, m, &cVar_X3YwYYfB_sendMessage);
}

void Heavy_vSwell::cCast_RNmAvzaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0BRJb1Iq_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_PZJPBsXh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jI6fJVUe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jI6fJVUe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cwXvZ3LW, 1, m, &cDelay_cwXvZ3LW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FFY8t2uX_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_cwXvZ3LW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cwXvZ3LW, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fQuDbcVn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jrS6EuZb_sendMessage);
  cSwitchcase_yy6UVG1H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_jI6fJVUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cwXvZ3LW, 0, m, &cDelay_cwXvZ3LW_sendMessage);
}

void Heavy_vSwell::cCast_FFY8t2uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cwXvZ3LW, 0, m, &cDelay_cwXvZ3LW_sendMessage);
}

void Heavy_vSwell::cVar_37RaWqAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sO2JZudU, HV_BINOP_MULTIPLY, 0, m, &cBinop_sO2JZudU_sendMessage);
}

void Heavy_vSwell::cMsg_8JUkq6uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I8o9mjwX_sendMessage);
}

void Heavy_vSwell::cSystem_I8o9mjwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zkwTjDOH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_sO2JZudU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CdC6LReD_sendMessage);
}

void Heavy_vSwell::cBinop_K6EBnPu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sO2JZudU, HV_BINOP_MULTIPLY, 1, m, &cBinop_sO2JZudU_sendMessage);
}

void Heavy_vSwell::cMsg_zkwTjDOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_K6EBnPu2_sendMessage);
}

void Heavy_vSwell::cBinop_CdC6LReD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_59kXPpSe_sendMessage);
}

void Heavy_vSwell::cBinop_59kXPpSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_blPOahvr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xpc2mmQm, m);
}

void Heavy_vSwell::cBinop_blPOahvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TTkUlP87, m);
}

void Heavy_vSwell::cMsg_VT0ip5L7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Jwpk7LYD_sendMessage);
}

void Heavy_vSwell::cSystem_Jwpk7LYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xA30G3YX_sendMessage);
}

void Heavy_vSwell::cDelay_OHH476hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OHH476hj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WnWWN0WF, 0, m, &cDelay_WnWWN0WF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OHH476hj, 0, m, &cDelay_OHH476hj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_E1m03V6U, 1, m, NULL);
}

void Heavy_vSwell::cDelay_WnWWN0WF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WnWWN0WF, m);
  cMsg_pyPgwNL6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_EramgML3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2rqsCrxM_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_BqJ719EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_guLopd0b_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OHH476hj, 2, m, &cDelay_OHH476hj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ybsYios_sendMessage);
}

void Heavy_vSwell::cMsg_2rqsCrxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_BqJ719EO, 0, m, &hTable_BqJ719EO_sendMessage);
}

void Heavy_vSwell::cBinop_xA30G3YX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_EramgML3_sendMessage);
}

void Heavy_vSwell::cMsg_pyPgwNL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_BqJ719EO, 0, m, &hTable_BqJ719EO_sendMessage);
}

void Heavy_vSwell::cCast_0ybsYios_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OHH476hj, 0, m, &cDelay_OHH476hj_sendMessage);
}

void Heavy_vSwell::cMsg_guLopd0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WnWWN0WF, 2, m, &cDelay_WnWWN0WF_sendMessage);
}

void Heavy_vSwell::cTabhead_niRFyR8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pGmDYQ1i, HV_BINOP_SUBTRACT, 0, m, &cBinop_pGmDYQ1i_sendMessage);
}

void Heavy_vSwell::cMsg_W8I5im2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kDJ1hBT9_sendMessage);
}

void Heavy_vSwell::cSystem_kDJ1hBT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MtggIUr0_sendMessage);
}

void Heavy_vSwell::cVar_1atglzQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_53kVoqkO_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_cHBN195U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cHBN195U, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUvYMwNU, 0, m, &cDelay_bUvYMwNU_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJabLwRp, 0, m, &sTabread_OJabLwRp_sendMessage);
}

void Heavy_vSwell::cDelay_bUvYMwNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bUvYMwNU, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJabLwRp, 0, m, &sTabread_OJabLwRp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUvYMwNU, 0, m, &cDelay_bUvYMwNU_sendMessage);
}

void Heavy_vSwell::sTabread_OJabLwRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_pMfo5gzU, HV_BINOP_SUBTRACT, 0, m, &cBinop_pMfo5gzU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_dpKMKLB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ugCQNQ11, HV_BINOP_MAX, 0, m, &cBinop_ugCQNQ11_sendMessage);
}

void Heavy_vSwell::cBinop_MtggIUr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dpKMKLB0, HV_BINOP_MULTIPLY, 0, m, &cBinop_dpKMKLB0_sendMessage);
}

void Heavy_vSwell::cBinop_pGmDYQ1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ep7RUS7V_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJabLwRp, 0, m, &sTabread_OJabLwRp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I1Xc2KCq_sendMessage);
}

void Heavy_vSwell::cSystem_SlGXhHlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pMfo5gzU, HV_BINOP_SUBTRACT, 1, m, &cBinop_pMfo5gzU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUvYMwNU, 2, m, &cDelay_bUvYMwNU_sendMessage);
}

void Heavy_vSwell::cMsg_53kVoqkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SlGXhHlp_sendMessage);
}

void Heavy_vSwell::cMsg_ep7RUS7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cHBN195U, 0, m, &cDelay_cHBN195U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUvYMwNU, 0, m, &cDelay_bUvYMwNU_sendMessage);
}

void Heavy_vSwell::cMsg_X1T0q7Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ugCQNQ11, HV_BINOP_MAX, 1, m, &cBinop_ugCQNQ11_sendMessage);
}

void Heavy_vSwell::cBinop_ugCQNQ11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pGmDYQ1i, HV_BINOP_SUBTRACT, 1, m, &cBinop_pGmDYQ1i_sendMessage);
}

void Heavy_vSwell::cCast_I1Xc2KCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cHBN195U, 0, m, &cDelay_cHBN195U_sendMessage);
}

void Heavy_vSwell::cBinop_MNrdv9T6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cHBN195U, 2, m, &cDelay_cHBN195U_sendMessage);
}

void Heavy_vSwell::cBinop_pMfo5gzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MNrdv9T6_sendMessage);
}

void Heavy_vSwell::cCast_O6MGWAfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1atglzQe, 0, m, &cVar_1atglzQe_sendMessage);
  cMsg_W8I5im2E_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_niRFyR8n, 0, m, &cTabhead_niRFyR8n_sendMessage);
}

void Heavy_vSwell::cUnop_BUmpnnPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JcN8nIkT, m);
}

void Heavy_vSwell::cCast_TNa8dPeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rve3aAdh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7PsICXrn, 0, m, &cVar_7PsICXrn_sendMessage);
}

void Heavy_vSwell::cCast_Fa0Ius7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PZJPBsXh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_fqKDsD8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sgSqQd6Q, 0, m, &cVar_sgSqQd6Q_sendMessage);
}

void Heavy_vSwell::cCast_odQnoFXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vNuH5SuF, HV_BINOP_SUBTRACT, 0, m, &cBinop_vNuH5SuF_sendMessage);
}

void Heavy_vSwell::cBinop_vNuH5SuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5XsSlVDh, 0, m, &cVar_5XsSlVDh_sendMessage);
}

void Heavy_vSwell::cSend_rve3aAdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oGaV55EG_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_Qd80KF6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F8oFgzNe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_TJVKX6jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_fE1t0vsd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_p301BIIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v8wsnSTc, 0, m, NULL);
}

void Heavy_vSwell::cSend_s8wLEIXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xKw5SApR_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_fjEuXCHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cwXvZ3LW, 1, m, &cDelay_cwXvZ3LW_sendMessage);
}

void Heavy_vSwell::cBinop_TC8h0L4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_BUmpnnPT_sendMessage);
}

void Heavy_vSwell::cReceive_jynxMxDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vNuH5SuF, HV_BINOP_SUBTRACT, 1, m, &cBinop_vNuH5SuF_sendMessage);
}

void Heavy_vSwell::cReceive_knWwYRe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EEN4aqZj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bosorgcn, 0, m, &cVar_bosorgcn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yWP0RQ90, 0, m, &cVar_yWP0RQ90_sendMessage);
  cMsg_8S1X0KEK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PVjgP8hK, 0, m, &cVar_PVjgP8hK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZtbNolyd, 0, m, &cVar_ZtbNolyd_sendMessage);
  cMsg_8JUkq6uv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_37RaWqAW, 0, m, &cVar_37RaWqAW_sendMessage);
  cMsg_VT0ip5L7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_s1da1DCc, 0, m, &cVar_s1da1DCc_sendMessage);
  cMsg_X1T0q7Kk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1atglzQe, 0, m, &cVar_1atglzQe_sendMessage);
  cMsg_W8I5im2E_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_niRFyR8n, 0, m, &cTabhead_niRFyR8n_sendMessage);
}

void Heavy_vSwell::cReceive_J58HdQG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_oaN8UdZa, 0, m, &cSlice_oaN8UdZa_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_hqEH5Ox5, 0, m, &cSlice_hqEH5Ox5_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_ltzaFLJr, 0, m, &cSlice_ltzaFLJr_sendMessage);
}

void Heavy_vSwell::cReceive_TKsyjdyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_knpUZ5Xi, m);
}

void Heavy_vSwell::cReceive_oGaV55EG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cshfHu6c_sendMessage(_c, 0, m);
  cMsg_vLsa7m6V_sendMessage(_c, 0, m);
  cMsg_Cy9NeG9k_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_R5HiD4Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_odQnoFXw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fqKDsD8Y_sendMessage);
}

void Heavy_vSwell::cReceive_ryqRU2Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TNa8dPeb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fa0Ius7A_sendMessage);
}

void Heavy_vSwell::cReceive_ppvKIxcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MPwbvObR, 1, m, &cIf_MPwbvObR_sendMessage);
}

void Heavy_vSwell::cReceive_eYISdHG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nFgK8DPH, 1, m, &cVar_nFgK8DPH_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_rIm8NvI9, 1, m, &cPack_rIm8NvI9_sendMessage);
}

void Heavy_vSwell::cReceive_OclijZ0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rIm8NvI9, 2, m, &cPack_rIm8NvI9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qDrddMgR, 1, m, &cDelay_qDrddMgR_sendMessage);
}

void Heavy_vSwell::cReceive_v6IV3d4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_OGal2EGX, 1, m, &cPack_OGal2EGX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4qZSE2IG, 1, m, &cVar_4qZSE2IG_sendMessage);
}

void Heavy_vSwell::cReceive_WA2qyrvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_OGal2EGX, 2, m, &cPack_OGal2EGX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GcFHGm7D, 1, m, &cDelay_GcFHGm7D_sendMessage);
}

void Heavy_vSwell::cReceive_KUOd7PNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EBY0s9nL, 2, m, &cPack_EBY0s9nL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XjAj76UU, 1, m, &cDelay_XjAj76UU_sendMessage);
}

void Heavy_vSwell::cReceive_xKw5SApR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s1da1DCc, 1, m, &cVar_s1da1DCc_sendMessage);
  cMsg_TJVKX6jy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7PsICXrn, 1, m, &cVar_7PsICXrn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P6PIE30V, 1, m, &cVar_P6PIE30V_sendMessage);
}

void Heavy_vSwell::cReceive_eVOpMJvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s8wLEIXs_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_sTbpEukI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_fjEuXCHm_sendMessage);
}

void Heavy_vSwell::cReceive_xYIEOyb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TC8h0L4W_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l4LmtVPk, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_E1m03V6U, VIf(I0));
    __hv_tabread_f(&sTabread_OJabLwRp, VOf(Bf0));
    __hv_varread_f(&sVarf_Xpc2mmQm, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_TTkUlP87, VOf(Bf2));
    __hv_rpole_f(&sRPole_LKtoqDDL, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_l4LmtVPk, VOf(Bf1));
    __hv_varread_f(&sVarf_JcN8nIkT, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_YGNIG7Yk, VIf(Bf3), &sEnv_YGNIG7Yk_sendMessage);
    __hv_line_f(&sLine_v8wsnSTc, VOf(Bf3));
    __hv_varread_f(&sVarf_knpUZ5Xi, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Qnb8xZNe, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed
}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
