/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabread.h"
#include "HvSignalEnvelope.h"
#include "HvSignalRPole.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvControlTabhead.h"
#include "HvSignalDel1.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlPack.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvTable.h"
#include "HvControlSystem.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_YGNIG7Yk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iBbC7JxZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_RFtvNK5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_vtf1Wxjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GH74eCfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_alpnKi4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gBCTqFVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oQjEeApx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CBllpU9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gJW56z9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Li34wdtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_w8pRQt5s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xQQFEhOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_6ceFydzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_riLSVUco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m6Ju8OoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9N7l3Tps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sK6AOiT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6HDQVDWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YEcSJyUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pcMQIMdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_873Idde6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_xpcCWz3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0h9bRCau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RkvB6BVg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fnk05c19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_09m5gsN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sgSqQd6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5XsSlVDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GWZNzTYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4gT8tdkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s7vReFsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6XBSfN4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_oaN8UdZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_hqEH5Ox5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ltzaFLJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yWP0RQ90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6VZXqUGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zKgR99A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_e9sjCvQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zP51Ihv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DHdZOK3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vYsJd13y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hCFjP6pJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wV4F9PQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aLuayjHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxZ3x9I3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n9KXfjyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v9cjTDgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9q8t1ZJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fFuztVnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xZ0JZN7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R3pRWzLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yy6UVG1H_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_qDrddMgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZaWYpYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xLglqOTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_rIm8NvI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P6PIE30V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cshfHu6c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fQuDbcVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jrS6EuZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oa6sR2yV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y5qjEzff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DtW9Hde7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_GcFHGm7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIaST7Zh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GQNAFcq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_OGal2EGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nFgK8DPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vLsa7m6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nOHmW5gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vWNTSTOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qhcuJsbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bAhtcxQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Z0q0jhYe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_XjAj76UU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gMqZsbaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eu2Z5OCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_EBY0s9nL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4qZSE2IG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cy9NeG9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cAeWIqAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fMANy2rV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Ia6SRBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LRP20RpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MPwbvObR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F8oFgzNe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_8wWWTDAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7PsICXrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s1da1DCc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8S1X0KEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6nNH9OHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iG6TxRkf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Cd4mIpGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sgEyuu47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EEN4aqZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kcYq1vAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bosorgcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8wg6T0ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tOtOhCUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x1Oco5QW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZSkJ0C4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_61N5KHIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F0xr9PQ0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Gfxt4gzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_12fhLqXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fE1t0vsd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mVPuAm2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_JiwgUx0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X3YwYYfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZtbNolyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q9VcoOOJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_zhcyZEpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PVjgP8hK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C8mbn1FS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7xRs8B5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ymzgoqBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_RSmA7Hz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FWT4pnie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h7CvpPwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gzbHqWeM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZqLtYoSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_asg0N8Ag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0BRJb1Iq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rh4Wz2h9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HCFeyogs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJMaCY4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6km8wYHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZwgJD4tN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sptpdylc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pUMjh59h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_41KGe7im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z1IZlQg0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ukyIJvXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FLpdKo7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XVSoKJGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yDIa8xeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6piFYbK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fecEVhxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NaNynuUq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QKP763EY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KBucz4w6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OXePGfJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IAPcwKNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ghn8mI6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RNmAvzaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PZJPBsXh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_cwXvZ3LW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jI6fJVUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FFY8t2uX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_37RaWqAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8JUkq6uv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I8o9mjwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sO2JZudU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K6EBnPu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkwTjDOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CdC6LReD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_59kXPpSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_blPOahvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VT0ip5L7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Jwpk7LYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OHH476hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WnWWN0WF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EramgML3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_BqJ719EO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2rqsCrxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xA30G3YX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pyPgwNL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ybsYios_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_guLopd0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_niRFyR8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W8I5im2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kDJ1hBT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1atglzQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cHBN195U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bUvYMwNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_OJabLwRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dpKMKLB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MtggIUr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pGmDYQ1i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SlGXhHlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_53kVoqkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ep7RUS7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X1T0q7Kk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ugCQNQ11_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I1Xc2KCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MNrdv9T6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pMfo5gzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6MGWAfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BUmpnnPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TNa8dPeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fa0Ius7A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fqKDsD8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_odQnoFXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vNuH5SuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rve3aAdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qd80KF6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TJVKX6jy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p301BIIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_s8wLEIXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fjEuXCHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TC8h0L4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jynxMxDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_knWwYRe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J58HdQG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TKsyjdyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oGaV55EG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R5HiD4Wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ryqRU2Cg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ppvKIxcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eYISdHG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OclijZ0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v6IV3d4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WA2qyrvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KUOd7PNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xKw5SApR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eVOpMJvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sTbpEukI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xYIEOyb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_E1m03V6U;
  SignalTabread sTabread_OJabLwRp;
  SignalRPole sRPole_LKtoqDDL;
  SignalEnvelope sEnv_YGNIG7Yk;
  SignalLine sLine_v8wsnSTc;
  ControlSlice cSlice_RFtvNK5g;
  ControlSlice cSlice_vtf1Wxjy;
  ControlVar cVar_GH74eCfD;
  ControlIf cIf_alpnKi4J;
  ControlBinop cBinop_CBllpU9Z;
  ControlSlice cSlice_xQQFEhOg;
  ControlSlice cSlice_6ceFydzd;
  ControlVar cVar_riLSVUco;
  ControlIf cIf_m6Ju8OoZ;
  ControlBinop cBinop_6HDQVDWW;
  ControlVar cVar_sgSqQd6Q;
  ControlVar cVar_5XsSlVDh;
  ControlBinop cBinop_GWZNzTYo;
  ControlBinop cBinop_4gT8tdkT;
  ControlSlice cSlice_oaN8UdZa;
  ControlSlice cSlice_hqEH5Ox5;
  ControlSlice cSlice_ltzaFLJr;
  ControlVar cVar_yWP0RQ90;
  ControlIf cIf_e9sjCvQB;
  ControlBinop cBinop_zP51Ihv1;
  ControlIf cIf_DHdZOK3m;
  ControlIf cIf_vYsJd13y;
  ControlIf cIf_hCFjP6pJ;
  ControlIf cIf_wV4F9PQQ;
  ControlBinop cBinop_aLuayjHX;
  ControlBinop cBinop_kxZ3x9I3;
  ControlBinop cBinop_n9KXfjyJ;
  ControlBinop cBinop_R3pRWzLa;
  ControlDelay cDelay_qDrddMgR;
  ControlPack cPack_rIm8NvI9;
  ControlVar cVar_P6PIE30V;
  ControlDelay cDelay_GcFHGm7D;
  ControlPack cPack_OGal2EGX;
  ControlVar cVar_nFgK8DPH;
  ControlDelay cDelay_XjAj76UU;
  ControlPack cPack_EBY0s9nL;
  ControlVar cVar_4qZSE2IG;
  ControlIf cIf_MPwbvObR;
  ControlVar cVar_7PsICXrn;
  ControlVar cVar_s1da1DCc;
  SignalVarf sVarf_Qnb8xZNe;
  ControlDelay cDelay_Cd4mIpGB;
  ControlVar cVar_bosorgcn;
  ControlBinop cBinop_tOtOhCUy;
  ControlBinop cBinop_x1Oco5QW;
  ControlBinop cBinop_ZSkJ0C4Z;
  ControlVar cVar_61N5KHIg;
  ControlSlice cSlice_mVPuAm2c;
  ControlSlice cSlice_JiwgUx0F;
  ControlVar cVar_X3YwYYfB;
  ControlVar cVar_ZtbNolyd;
  ControlVar cVar_PVjgP8hK;
  ControlVar cVar_C8mbn1FS;
  ControlVar cVar_7xRs8B5M;
  ControlSlice cSlice_ymzgoqBQ;
  ControlSlice cSlice_RSmA7Hz3;
  ControlBinop cBinop_FWT4pnie;
  ControlBinop cBinop_h7CvpPwk;
  ControlBinop cBinop_gzbHqWeM;
  ControlBinop cBinop_ZqLtYoSW;
  ControlBinop cBinop_asg0N8Ag;
  ControlBinop cBinop_HCFeyogs;
  ControlBinop cBinop_sJMaCY4v;
  ControlBinop cBinop_6km8wYHn;
  ControlBinop cBinop_ZwgJD4tN;
  ControlBinop cBinop_XVSoKJGh;
  ControlBinop cBinop_KBucz4w6;
  ControlDelay cDelay_cwXvZ3LW;
  ControlVar cVar_37RaWqAW;
  ControlBinop cBinop_sO2JZudU;
  ControlBinop cBinop_K6EBnPu2;
  SignalVarf sVarf_TTkUlP87;
  ControlBinop cBinop_CdC6LReD;
  ControlBinop cBinop_59kXPpSe;
  ControlBinop cBinop_blPOahvr;
  SignalVarf sVarf_Xpc2mmQm;
  ControlDelay cDelay_OHH476hj;
  ControlDelay cDelay_WnWWN0WF;
  ControlBinop cBinop_EramgML3;
  HvTable hTable_BqJ719EO;
  ControlBinop cBinop_xA30G3YX;
  ControlTabhead cTabhead_niRFyR8n;
  ControlVar cVar_1atglzQe;
  ControlDelay cDelay_cHBN195U;
  ControlDelay cDelay_bUvYMwNU;
  ControlBinop cBinop_dpKMKLB0;
  ControlBinop cBinop_MtggIUr0;
  ControlBinop cBinop_pGmDYQ1i;
  ControlBinop cBinop_ugCQNQ11;
  ControlBinop cBinop_MNrdv9T6;
  ControlBinop cBinop_pMfo5gzU;
  ControlBinop cBinop_vNuH5SuF;
  ControlBinop cBinop_Qd80KF6K;
  ControlBinop cBinop_fjEuXCHm;
  ControlBinop cBinop_TC8h0L4W;
  SignalVarf sVarf_knpUZ5Xi;
  SignalVarf sVarf_JcN8nIkT;
  SignalVarf sVarf_l4LmtVPk;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
