/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_0LNC8DPs, &hTable_ELCoSslG);
  numBytes += sTabwrite_init(&sTabwrite_EWG1og67, &hTable_RNf6PZSA);
  numBytes += sRPole_init(&sRPole_BlUHULlb);
  numBytes += sEnv_init(&sEnv_LTjp6YAn, 1024, 512);
  numBytes += sTabread_init(&sTabread_aOdpk9kg, &hTable_ELCoSslG, true);
  numBytes += sLine_init(&sLine_KITMLmtA);
  numBytes += sTabread_init(&sTabread_8dRWFNXL, &hTable_RNf6PZSA, true);
  numBytes += cSlice_init(&cSlice_XJQOGN2h, 1, -1);
  numBytes += cSlice_init(&cSlice_1d5yNqep, 1, -1);
  numBytes += cVar_init_f(&cVar_n7lkLbse, 0.0f);
  numBytes += cIf_init(&cIf_liISiFBJ, false);
  numBytes += cBinop_init(&cBinop_XBVaIxv3, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_XPekIGRW, 1, -1);
  numBytes += cSlice_init(&cSlice_tQ3q2Lur, 1, -1);
  numBytes += cVar_init_f(&cVar_z6u7Pvbx, 0.0f);
  numBytes += cIf_init(&cIf_ajn3S4yd, false);
  numBytes += cBinop_init(&cBinop_H33gbnMN, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_6DOALVgx, 0.0f);
  numBytes += cVar_init_f(&cVar_gIuH52Zp, 0.0f);
  numBytes += cBinop_init(&cBinop_fXeCsSgK, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_I3LeJfzG, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_ang1yS3e, 2, 1);
  numBytes += cSlice_init(&cSlice_WLP1YsSK, 1, 1);
  numBytes += cSlice_init(&cSlice_5zYPswgG, 0, 1);
  numBytes += cVar_init_f(&cVar_4Sq692HK, 0.0f);
  numBytes += cIf_init(&cIf_K6ATMhCe, false);
  numBytes += cIf_init(&cIf_jtB1zC8q, false);
  numBytes += cIf_init(&cIf_8lFfmjG0, false);
  numBytes += cIf_init(&cIf_QSqmJVlp, false);
  numBytes += cIf_init(&cIf_xVSX5LZO, false);
  numBytes += cBinop_init(&cBinop_MTXcdFqr, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_cCDSr0sO, 10.0f);
  numBytes += cPack_init(&cPack_0vV4elc9, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_u9LQBQeg, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_OF5OxHW5, 10.0f);
  numBytes += cPack_init(&cPack_x41LckyF, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_tKS4IvzY, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_u3uAki1v, 10.0f);
  numBytes += cPack_init(&cPack_wRxJrEty, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_ZKaHJGl2, 1e-07f);
  numBytes += cVar_init_f(&cVar_RLMfWWtX, 1e-07f);
  numBytes += cVar_init_f(&cVar_Ys2BsSdr, 1e-07f);
  numBytes += sVarf_init(&sVarf_t0iNg1BW, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_RDiqbbma, 0.0f);
  numBytes += cVar_init_f(&cVar_2E9Oqwpv, 20.0f);
  numBytes += cBinop_init(&cBinop_Hvx1ZBb9, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Z5WEn3JK, 0.0f);
  numBytes += cSlice_init(&cSlice_xXsZoTYG, 1, -1);
  numBytes += cSlice_init(&cSlice_hmYZIBuo, 1, -1);
  numBytes += cVar_init_f(&cVar_LJfdkluu, 0.0f);
  numBytes += cVar_init_f(&cVar_zLsoyZQy, 20.0f);
  numBytes += cVar_init_f(&cVar_CF3mGQfa, 0.0f);
  numBytes += cVar_init_f(&cVar_IL2m0JaI, 0.0f);
  numBytes += cVar_init_f(&cVar_RH1pYNDC, 0.0f);
  numBytes += cSlice_init(&cSlice_iVxGsVud, 1, 1);
  numBytes += cSlice_init(&cSlice_SgAmmAQO, 0, 1);
  numBytes += cBinop_init(&cBinop_3h4ke7ZP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sStZK1mH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EfNxXRtz, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_GNi97YHM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_16mQIwDz, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_Fh9Dvhpv, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_OW4OUYkG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JN1o9r8O, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Ik0pioAy, 5.0f);
  numBytes += cVar_init_f(&cVar_UfFTooyd, 500.0f);
  numBytes += cBinop_init(&cBinop_GKOSluOW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xGh3uZdH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MD5A8yBg, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_hkVnDLo8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Q6lCC2LL, 0.0f);
  numBytes += hTable_init(&hTable_ELCoSslG, 256);
  numBytes += cTabhead_init(&cTabhead_sSiyvxfy, &hTable_ELCoSslG);
  numBytes += cVar_init_s(&cVar_YGmhdjh1, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_Q4P8u8eS, 8.0f);
  numBytes += cDelay_init(this, &cDelay_GlpYsAA5, 0.0f);
  numBytes += cBinop_init(&cBinop_GxKn0K4b, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_xiJoX6sL, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_BvHwU6EW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fAckA7rW, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ZYUoAvFE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_toPxRuD3, 0.0f);
  numBytes += hTable_init(&hTable_RNf6PZSA, 256);
  numBytes += cTabhead_init(&cTabhead_LtGWAPmE, &hTable_RNf6PZSA);
  numBytes += cVar_init_s(&cVar_4rXpdvgS, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_KidgGWvQ, 8.0f);
  numBytes += cDelay_init(this, &cDelay_sjZ2LCq9, 0.0f);
  numBytes += cBinop_init(&cBinop_Q3urBTiD, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_S0MeeFaZ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Fq8OxnFE, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_pCapPv46, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_TUiwt4w7, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_KryO01T1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QdzwVIYZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SpMMaleu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QYpOXIKg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RmIQ1epe, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_LTjp6YAn);
  cPack_free(&cPack_0vV4elc9);
  cPack_free(&cPack_x41LckyF);
  cPack_free(&cPack_wRxJrEty);
  hTable_free(&hTable_ELCoSslG);
  hTable_free(&hTable_RNf6PZSA);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_ELCoSslG; // del-1001-swell
    case 0x505A9C79: return &hTable_RNf6PZSA; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFKf8iOi_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2TmbmdR2_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FngYTDKV_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ESFNhv8b_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bdEAkVbf_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uzTbMO6U_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KocnvcJ3_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sIAVXUv1_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TrTHHXxs_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HEsyLLjG_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GGsysZWk_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aNvCdjcJ_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_agicMr81_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jd8ZSBxV_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4IdyPtGf_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UoZ9baqo_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L1Juep6Q_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DvZeKCAo_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_LTjp6YAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fXeCsSgK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fXeCsSgK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I3LeJfzG, HV_BINOP_LESS_THAN, 0, m, &cBinop_I3LeJfzG_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Ga4cN8YX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XJQOGN2h, 0, m, &cSlice_XJQOGN2h_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1d5yNqep, 0, m, &cSlice_1d5yNqep_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7RJqmOoa_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PhY1itCU_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_XJQOGN2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_n7lkLbse, 0, m, &cVar_n7lkLbse_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_n7lkLbse, 0, m, &cVar_n7lkLbse_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_1d5yNqep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XBVaIxv3, HV_BINOP_NEQ, 1, m, &cBinop_XBVaIxv3_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_n7lkLbse, 1, m, &cVar_n7lkLbse_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XBVaIxv3, HV_BINOP_NEQ, 1, m, &cBinop_XBVaIxv3_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_n7lkLbse, 1, m, &cVar_n7lkLbse_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_n7lkLbse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_O54NEOtn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_liISiFBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vMNayvPn_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C3ja6VfX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_C3ja6VfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n7lkLbse, 0, m, &cVar_n7lkLbse_sendMessage);
}

void Heavy_vSwellST::cCast_vMNayvPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBVaIxv3, HV_BINOP_NEQ, 1, m, &cBinop_XBVaIxv3_sendMessage);
}

void Heavy_vSwellST::cBinop_XBVaIxv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liISiFBJ, 1, m, &cIf_liISiFBJ_sendMessage);
}

void Heavy_vSwellST::cCast_PhY1itCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liISiFBJ, 0, m, &cIf_liISiFBJ_sendMessage);
}

void Heavy_vSwellST::cCast_7RJqmOoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBVaIxv3, HV_BINOP_NEQ, 0, m, &cBinop_XBVaIxv3_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_sWHLB7yU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XPekIGRW, 0, m, &cSlice_XPekIGRW_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tQ3q2Lur, 0, m, &cSlice_tQ3q2Lur_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bf6zeyzR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wBTSVJ6h_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_XPekIGRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_z6u7Pvbx, 0, m, &cVar_z6u7Pvbx_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_z6u7Pvbx, 0, m, &cVar_z6u7Pvbx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_tQ3q2Lur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_H33gbnMN, HV_BINOP_NEQ, 1, m, &cBinop_H33gbnMN_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_z6u7Pvbx, 1, m, &cVar_z6u7Pvbx_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_H33gbnMN, HV_BINOP_NEQ, 1, m, &cBinop_H33gbnMN_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_z6u7Pvbx, 1, m, &cVar_z6u7Pvbx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_z6u7Pvbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_afBYRFsn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_ajn3S4yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4p4IGshu_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xR9zgtk1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_4p4IGshu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H33gbnMN, HV_BINOP_NEQ, 1, m, &cBinop_H33gbnMN_sendMessage);
}

void Heavy_vSwellST::cCast_xR9zgtk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z6u7Pvbx, 0, m, &cVar_z6u7Pvbx_sendMessage);
}

void Heavy_vSwellST::cBinop_H33gbnMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajn3S4yd, 1, m, &cIf_ajn3S4yd_sendMessage);
}

void Heavy_vSwellST::cCast_Bf6zeyzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H33gbnMN, HV_BINOP_NEQ, 0, m, &cBinop_H33gbnMN_sendMessage);
}

void Heavy_vSwellST::cCast_wBTSVJ6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajn3S4yd, 0, m, &cIf_ajn3S4yd_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_O54NEOtn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ni6iFSAs_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2r4fNRLg_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_ni6iFSAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gIuH52Zp, 0, m, &cVar_gIuH52Zp_sendMessage);
}

void Heavy_vSwellST::cCast_2r4fNRLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u7nHVYUc_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pwOFWbaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASZJU4qo_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_afBYRFsn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_44xHJ4HQ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1j5RLm1j_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_44xHJ4HQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6DOALVgx, 0, m, &cVar_6DOALVgx_sendMessage);
}

void Heavy_vSwellST::cCast_1j5RLm1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6alWrZhE_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_6DOALVgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fXeCsSgK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fXeCsSgK_sendMessage);
}

void Heavy_vSwellST::cVar_gIuH52Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I3LeJfzG, HV_BINOP_LESS_THAN, 1, m, &cBinop_I3LeJfzG_sendMessage);
}

void Heavy_vSwellST::cBinop_fXeCsSgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ga4cN8YX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_I3LeJfzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sWHLB7yU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_u7nHVYUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fXeCsSgK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fXeCsSgK_sendMessage);
}

void Heavy_vSwellST::cMsg_6alWrZhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I3LeJfzG, HV_BINOP_LESS_THAN, 1, m, &cBinop_I3LeJfzG_sendMessage);
}

void Heavy_vSwellST::cSlice_ang1yS3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_byhe2s4q_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_WLP1YsSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_QSqmJVlp, 0, m, &cIf_QSqmJVlp_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_jtB1zC8q, 0, m, &cIf_jtB1zC8q_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_5zYPswgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_xVSX5LZO, 0, m, &cIf_xVSX5LZO_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_8lFfmjG0, 0, m, &cIf_8lFfmjG0_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_4Sq692HK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GT8hf5pN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_K6ATMhCe, 0, m, &cIf_K6ATMhCe_sendMessage);
}

void Heavy_vSwellST::cUnop_hkRjRjfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_le9sQ0i8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MTXcdFqr, HV_BINOP_EQ, 1, m, &cBinop_MTXcdFqr_sendMessage);
}

void Heavy_vSwellST::cUnop_WCwa9Uh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_le9sQ0i8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MTXcdFqr, HV_BINOP_EQ, 1, m, &cBinop_MTXcdFqr_sendMessage);
}

void Heavy_vSwellST::cIf_K6ATMhCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_WCwa9Uh3_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_hkRjRjfy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_GT8hf5pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K6ATMhCe, 1, m, &cIf_K6ATMhCe_sendMessage);
}

void Heavy_vSwellST::cIf_jtB1zC8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_s8fqHjiL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_8lFfmjG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_QSqmJVlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_s8fqHjiL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_xVSX5LZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_byhe2s4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MTXcdFqr, HV_BINOP_EQ, 0, m, &cBinop_MTXcdFqr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_IxPO7yIm_sendMessage);
}

void Heavy_vSwellST::cBinop_le9sQ0i8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sAEBBJmr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcJSHaCo_sendMessage);
}

void Heavy_vSwellST::cBinop_MTXcdFqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_70dcWC4E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8E2pxrug_sendMessage);
}

void Heavy_vSwellST::cCast_70dcWC4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jtB1zC8q, 1, m, &cIf_jtB1zC8q_sendMessage);
}

void Heavy_vSwellST::cCast_8E2pxrug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xVSX5LZO, 1, m, &cIf_xVSX5LZO_sendMessage);
}

void Heavy_vSwellST::cCast_OcJSHaCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8lFfmjG0, 1, m, &cIf_8lFfmjG0_sendMessage);
}

void Heavy_vSwellST::cCast_sAEBBJmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QSqmJVlp, 1, m, &cIf_QSqmJVlp_sendMessage);
}

void Heavy_vSwellST::cBinop_IxPO7yIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_zdRot9na_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KAD7Mxz2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KAD7Mxz2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cCDSr0sO, 1, m, &cDelay_cCDSr0sO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w3Rdyizq_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_cCDSr0sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cCDSr0sO, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gFnKTD3T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ypKSu23W_sendMessage);
  cSwitchcase_zRoKL00a_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_KAD7Mxz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cCDSr0sO, 0, m, &cDelay_cCDSr0sO_sendMessage);
}

void Heavy_vSwellST::cCast_w3Rdyizq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cCDSr0sO, 0, m, &cDelay_cCDSr0sO_sendMessage);
}

void Heavy_vSwellST::cPack_0vV4elc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QzP6hpJe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_u9LQBQeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Em1647Qh_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_15nF0fxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_zdRot9na_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_LJKYFsVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u9LQBQeg, 0, m, &cVar_u9LQBQeg_sendMessage);
}

void Heavy_vSwellST::cCast_DA3Sbekb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0vV4elc9, 0, m, &cPack_0vV4elc9_sendMessage);
}

void Heavy_vSwellST::cMsg_Em1647Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_QzP6hpJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_zRoKL00a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_B8s2mzsU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_B8s2mzsU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OF5OxHW5, 1, m, &cDelay_OF5OxHW5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2B7CJlRz_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_OF5OxHW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OF5OxHW5, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5WwcbU3A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vJwrlHfk_sendMessage);
  cSwitchcase_5Xof9dOC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_B8s2mzsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OF5OxHW5, 0, m, &cDelay_OF5OxHW5_sendMessage);
}

void Heavy_vSwellST::cCast_2B7CJlRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OF5OxHW5, 0, m, &cDelay_OF5OxHW5_sendMessage);
}

void Heavy_vSwellST::cPack_x41LckyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ByfrajwX_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_tKS4IvzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RB6Rp0TV_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_ZwizLXem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_zRoKL00a_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_ypKSu23W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_x41LckyF, 0, m, &cPack_x41LckyF_sendMessage);
}

void Heavy_vSwellST::cCast_gFnKTD3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKS4IvzY, 0, m, &cVar_tKS4IvzY_sendMessage);
}

void Heavy_vSwellST::cMsg_RB6Rp0TV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_ByfrajwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_5Xof9dOC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3ggnc0JM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3ggnc0JM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_u3uAki1v, 1, m, &cDelay_u3uAki1v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6bw81vP0_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_u3uAki1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u3uAki1v, m);
}

void Heavy_vSwellST::cMsg_3ggnc0JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_u3uAki1v, 0, m, &cDelay_u3uAki1v_sendMessage);
}

void Heavy_vSwellST::cCast_6bw81vP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_u3uAki1v, 0, m, &cDelay_u3uAki1v_sendMessage);
}

void Heavy_vSwellST::cPack_wRxJrEty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xuAFXr5T_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_ZKaHJGl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tnM0Dd7v_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_8wAgsGoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_5Xof9dOC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_5WwcbU3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZKaHJGl2, 0, m, &cVar_ZKaHJGl2_sendMessage);
}

void Heavy_vSwellST::cCast_vJwrlHfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wRxJrEty, 0, m, &cPack_wRxJrEty_sendMessage);
}

void Heavy_vSwellST::cMsg_tnM0Dd7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_xuAFXr5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_TaQP8hBV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4kRHhK2U_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_4kRHhK2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pwOFWbaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASZJU4qo_sendMessage);
}

void Heavy_vSwellST::cVar_RLMfWWtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oWWRNkqm_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_Ys2BsSdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wRxJrEty, 1, m, &cPack_wRxJrEty_sendMessage);
}

void Heavy_vSwellST::cMsg_OstD2gML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PRHSwPVw_sendMessage);
}

void Heavy_vSwellST::cSystem_PRHSwPVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sStZK1mH, HV_BINOP_MULTIPLY, 1, m, &cBinop_sStZK1mH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3h4ke7ZP, HV_BINOP_MULTIPLY, 1, m, &cBinop_3h4ke7ZP_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_MkCKhQTF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cMsg_FbmNDjq3_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_FbmNDjq3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AzAInbBU_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_RDiqbbma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RDiqbbma, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDiqbbma, 0, m, &cDelay_RDiqbbma_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z5WEn3JK, 0, m, &cVar_Z5WEn3JK_sendMessage);
}

void Heavy_vSwellST::cCast_AzAInbBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FbmNDjq3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDiqbbma, 0, m, &cDelay_RDiqbbma_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z5WEn3JK, 0, m, &cVar_Z5WEn3JK_sendMessage);
}

void Heavy_vSwellST::cMsg_2kz5ucnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ru5xAIZe_sendMessage);
}

void Heavy_vSwellST::cSystem_ru5xAIZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YNZErRI2_sendMessage);
}

void Heavy_vSwellST::cVar_2E9Oqwpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hvx1ZBb9, HV_BINOP_MULTIPLY, 0, m, &cBinop_Hvx1ZBb9_sendMessage);
}

void Heavy_vSwellST::cMsg_FbmNDjq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDiqbbma, 0, m, &cDelay_RDiqbbma_sendMessage);
}

void Heavy_vSwellST::cBinop_JImPSoYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDiqbbma, 2, m, &cDelay_RDiqbbma_sendMessage);
}

void Heavy_vSwellST::cBinop_YNZErRI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hvx1ZBb9, HV_BINOP_MULTIPLY, 1, m, &cBinop_Hvx1ZBb9_sendMessage);
}

void Heavy_vSwellST::cBinop_Hvx1ZBb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_JImPSoYw_sendMessage);
}

void Heavy_vSwellST::cVar_Z5WEn3JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfNxXRtz, HV_BINOP_SUBTRACT, 0, m, &cBinop_EfNxXRtz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_5yIm9lpZ_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_oMDLlw8E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4Qqu4be2_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3niOLePp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_4Qqu4be2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RH1pYNDC, 0, m, &cVar_RH1pYNDC_sendMessage);
}

void Heavy_vSwellST::cCast_3niOLePp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kE9yrWhk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YWbFpv0G_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_kDdyT3rk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xXsZoTYG, 0, m, &cSlice_xXsZoTYG_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hmYZIBuo, 0, m, &cSlice_hmYZIBuo_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VHxxqLow_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_iVxGsVud, 0, m, &cSlice_iVxGsVud_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_SgAmmAQO, 0, m, &cSlice_SgAmmAQO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4kKZx0EM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6nVMLo9_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_xXsZoTYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JIq2Ne4d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_JIq2Ne4d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_hmYZIBuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jzPmgkLS_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WV6MJK3i_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jzPmgkLS_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WV6MJK3i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_LJfdkluu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dlXMbXq8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2nV0go2H_sendMessage);
}

void Heavy_vSwellST::cVar_zLsoyZQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_niWEhOng_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_niWEhOng_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g7tCcVXG_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sStZK1mH, HV_BINOP_MULTIPLY, 0, m, &cBinop_sStZK1mH_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_16mQIwDz, HV_BINOP_DIVIDE, 1, m, &cBinop_16mQIwDz_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2E9Oqwpv, 0, m, &cVar_2E9Oqwpv_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_g7tCcVXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FQm2YnXQ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_CF3mGQfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JN1o9r8O, HV_BINOP_SUBTRACT, 1, m, &cBinop_JN1o9r8O_sendMessage);
}

void Heavy_vSwellST::cVar_IL2m0JaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RH1pYNDC, 0, m, &cVar_RH1pYNDC_sendMessage);
}

void Heavy_vSwellST::cVar_RH1pYNDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GNi97YHM, HV_BINOP_ADD, 0, m, &cBinop_GNi97YHM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OW4OUYkG, HV_BINOP_ADD, 0, m, &cBinop_OW4OUYkG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_t0iNg1BW, m);
}

void Heavy_vSwellST::cSlice_iVxGsVud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dlXMbXq8_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2nV0go2H_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_SgAmmAQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9rcckUDU_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AJ2qBmRG_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_m8i9OsFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z5WEn3JK, 1, m, &cVar_Z5WEn3JK_sendMessage);
}

void Heavy_vSwellST::cBinop_3h4ke7ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m8i9OsFs_sendMessage);
}

void Heavy_vSwellST::cBinop_sStZK1mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3Ox5s7CP_sendMessage);
}

void Heavy_vSwellST::cBinop_3Ox5s7CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfNxXRtz, HV_BINOP_SUBTRACT, 1, m, &cBinop_EfNxXRtz_sendMessage);
}

void Heavy_vSwellST::cBinop_EfNxXRtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z5WEn3JK, 1, m, &cVar_Z5WEn3JK_sendMessage);
}

void Heavy_vSwellST::cMsg_4D52VndU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_MkCKhQTF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_sVhVYa67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_MkCKhQTF_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OW4OUYkG, HV_BINOP_ADD, 1, m, &cBinop_OW4OUYkG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GNi97YHM, HV_BINOP_ADD, 1, m, &cBinop_GNi97YHM_sendMessage);
}

void Heavy_vSwellST::cBinop_5yIm9lpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oMDLlw8E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_GNi97YHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RH1pYNDC, 1, m, &cVar_RH1pYNDC_sendMessage);
}

void Heavy_vSwellST::cBinop_16mQIwDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fh9Dvhpv, HV_BINOP_DIVIDE, 1, m, &cBinop_Fh9Dvhpv_sendMessage);
}

void Heavy_vSwellST::cBinop_Fh9Dvhpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OW4OUYkG, HV_BINOP_ADD, 1, m, &cBinop_OW4OUYkG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GNi97YHM, HV_BINOP_ADD, 1, m, &cBinop_GNi97YHM_sendMessage);
}

void Heavy_vSwellST::cCast_dlXMbXq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3h4ke7ZP, HV_BINOP_MULTIPLY, 0, m, &cBinop_3h4ke7ZP_sendMessage);
}

void Heavy_vSwellST::cCast_2nV0go2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_16mQIwDz, HV_BINOP_DIVIDE, 0, m, &cBinop_16mQIwDz_sendMessage);
}

void Heavy_vSwellST::cCast_AJ2qBmRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JN1o9r8O, HV_BINOP_SUBTRACT, 0, m, &cBinop_JN1o9r8O_sendMessage);
}

void Heavy_vSwellST::cCast_9rcckUDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IL2m0JaI, 1, m, &cVar_IL2m0JaI_sendMessage);
}

void Heavy_vSwellST::cCast_YWbFpv0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IL2m0JaI, 0, m, &cVar_IL2m0JaI_sendMessage);
}

void Heavy_vSwellST::cCast_kE9yrWhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sVhVYa67_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_OW4OUYkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CF3mGQfa, 0, m, &cVar_CF3mGQfa_sendMessage);
}

void Heavy_vSwellST::cMsg_JIq2Ne4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_MkCKhQTF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_F8GqdXQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LJfdkluu, 1, m, &cVar_LJfdkluu_sendMessage);
}

void Heavy_vSwellST::cMsg_FQm2YnXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sStZK1mH, HV_BINOP_MULTIPLY, 0, m, &cBinop_sStZK1mH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_16mQIwDz, HV_BINOP_DIVIDE, 1, m, &cBinop_16mQIwDz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2E9Oqwpv, 0, m, &cVar_2E9Oqwpv_sendMessage);
}

void Heavy_vSwellST::cCast_WV6MJK3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ypWRASg9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OW4OUYkG, HV_BINOP_ADD, 0, m, &cBinop_OW4OUYkG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RH1pYNDC, 1, m, &cVar_RH1pYNDC_sendMessage);
}

void Heavy_vSwellST::cCast_jzPmgkLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JIq2Ne4d_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_JN1o9r8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fh9Dvhpv, HV_BINOP_DIVIDE, 0, m, &cBinop_Fh9Dvhpv_sendMessage);
}

void Heavy_vSwellST::cCast_ypWRASg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sVhVYa67_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_U6nVMLo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8GqdXQe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_4kKZx0EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4D52VndU_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_VHxxqLow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LJfdkluu, 0, m, &cVar_LJfdkluu_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_GfKQzOOc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AjvpawCf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AjvpawCf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ik0pioAy, 1, m, &cDelay_Ik0pioAy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1YSehE8M_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Ik0pioAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ik0pioAy, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LJKYFsVm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DA3Sbekb_sendMessage);
  cSwitchcase_zdRot9na_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_AjvpawCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ik0pioAy, 0, m, &cDelay_Ik0pioAy_sendMessage);
}

void Heavy_vSwellST::cCast_1YSehE8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ik0pioAy, 0, m, &cDelay_Ik0pioAy_sendMessage);
}

void Heavy_vSwellST::cVar_UfFTooyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GKOSluOW, HV_BINOP_MULTIPLY, 0, m, &cBinop_GKOSluOW_sendMessage);
}

void Heavy_vSwellST::cMsg_foVyDfyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xF72kAsl_sendMessage);
}

void Heavy_vSwellST::cSystem_xF72kAsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zXrqKOoK_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_GKOSluOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OHDvk4y0_sendMessage);
}

void Heavy_vSwellST::cBinop_hafx5hJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GKOSluOW, HV_BINOP_MULTIPLY, 1, m, &cBinop_GKOSluOW_sendMessage);
}

void Heavy_vSwellST::cMsg_zXrqKOoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hafx5hJp_sendMessage);
}

void Heavy_vSwellST::cBinop_OHDvk4y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_K5uWkRSB_sendMessage);
}

void Heavy_vSwellST::cBinop_K5uWkRSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_exNnzJQU_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MD5A8yBg, m);
}

void Heavy_vSwellST::cBinop_exNnzJQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xGh3uZdH, m);
}

void Heavy_vSwellST::cMsg_93TUbBPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OaACDTBX_sendMessage);
}

void Heavy_vSwellST::cSystem_OaACDTBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5JHF5jqv_sendMessage);
}

void Heavy_vSwellST::cDelay_hkVnDLo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hkVnDLo8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q6lCC2LL, 0, m, &cDelay_Q6lCC2LL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkVnDLo8, 0, m, &cDelay_hkVnDLo8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0LNC8DPs, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_Q6lCC2LL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q6lCC2LL, m);
  cMsg_os9ccqKd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_BXLTf942_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1LiD5bN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_ELCoSslG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t3TUZKoY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkVnDLo8, 2, m, &cDelay_hkVnDLo8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OCfVJBGS_sendMessage);
}

void Heavy_vSwellST::cMsg_r1LiD5bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ELCoSslG, 0, m, &hTable_ELCoSslG_sendMessage);
}

void Heavy_vSwellST::cBinop_5JHF5jqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_BXLTf942_sendMessage);
}

void Heavy_vSwellST::cMsg_os9ccqKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ELCoSslG, 0, m, &hTable_ELCoSslG_sendMessage);
}

void Heavy_vSwellST::cCast_OCfVJBGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkVnDLo8, 0, m, &cDelay_hkVnDLo8_sendMessage);
}

void Heavy_vSwellST::cMsg_t3TUZKoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q6lCC2LL, 2, m, &cDelay_Q6lCC2LL_sendMessage);
}

void Heavy_vSwellST::cTabhead_sSiyvxfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xiJoX6sL, HV_BINOP_SUBTRACT, 0, m, &cBinop_xiJoX6sL_sendMessage);
}

void Heavy_vSwellST::cMsg_MzYFITjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_temBoxRy_sendMessage);
}

void Heavy_vSwellST::cSystem_temBoxRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QpkdZ5aO_sendMessage);
}

void Heavy_vSwellST::cVar_YGmhdjh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mSf3ZFZl_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_Q4P8u8eS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q4P8u8eS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GlpYsAA5, 0, m, &cDelay_GlpYsAA5_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aOdpk9kg, 0, m, &sTabread_aOdpk9kg_sendMessage);
}

void Heavy_vSwellST::cDelay_GlpYsAA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GlpYsAA5, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aOdpk9kg, 0, m, &sTabread_aOdpk9kg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GlpYsAA5, 0, m, &cDelay_GlpYsAA5_sendMessage);
}

void Heavy_vSwellST::sTabread_aOdpk9kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fAckA7rW, HV_BINOP_SUBTRACT, 0, m, &cBinop_fAckA7rW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_GxKn0K4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BvHwU6EW, HV_BINOP_MAX, 0, m, &cBinop_BvHwU6EW_sendMessage);
}

void Heavy_vSwellST::cBinop_QpkdZ5aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GxKn0K4b, HV_BINOP_MULTIPLY, 0, m, &cBinop_GxKn0K4b_sendMessage);
}

void Heavy_vSwellST::cBinop_xiJoX6sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjNJrQHp_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aOdpk9kg, 0, m, &sTabread_aOdpk9kg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WqTqBBk5_sendMessage);
}

void Heavy_vSwellST::cSystem_YM1gg9Dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAckA7rW, HV_BINOP_SUBTRACT, 1, m, &cBinop_fAckA7rW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GlpYsAA5, 2, m, &cDelay_GlpYsAA5_sendMessage);
}

void Heavy_vSwellST::cMsg_mSf3ZFZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YM1gg9Dm_sendMessage);
}

void Heavy_vSwellST::cMsg_JjNJrQHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q4P8u8eS, 0, m, &cDelay_Q4P8u8eS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GlpYsAA5, 0, m, &cDelay_GlpYsAA5_sendMessage);
}

void Heavy_vSwellST::cMsg_Val4y3BH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_BvHwU6EW, HV_BINOP_MAX, 1, m, &cBinop_BvHwU6EW_sendMessage);
}

void Heavy_vSwellST::cBinop_BvHwU6EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xiJoX6sL, HV_BINOP_SUBTRACT, 1, m, &cBinop_xiJoX6sL_sendMessage);
}

void Heavy_vSwellST::cCast_WqTqBBk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q4P8u8eS, 0, m, &cDelay_Q4P8u8eS_sendMessage);
}

void Heavy_vSwellST::cBinop_yy5gUnZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q4P8u8eS, 2, m, &cDelay_Q4P8u8eS_sendMessage);
}

void Heavy_vSwellST::cBinop_fAckA7rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yy5gUnZA_sendMessage);
}

void Heavy_vSwellST::cCast_FzyofK2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YGmhdjh1, 0, m, &cVar_YGmhdjh1_sendMessage);
  cMsg_MzYFITjt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sSiyvxfy, 0, m, &cTabhead_sSiyvxfy_sendMessage);
}

void Heavy_vSwellST::cMsg_NU8gzKJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p8ExBr7G_sendMessage);
}

void Heavy_vSwellST::cSystem_p8ExBr7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4RL06sBl_sendMessage);
}

void Heavy_vSwellST::cDelay_ZYUoAvFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZYUoAvFE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_toPxRuD3, 0, m, &cDelay_toPxRuD3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZYUoAvFE, 0, m, &cDelay_ZYUoAvFE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EWG1og67, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_toPxRuD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_toPxRuD3, m);
  cMsg_hqgsdRhz_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_yGtaZaED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wqd0134y_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_RNf6PZSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nm7ie67G_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZYUoAvFE, 2, m, &cDelay_ZYUoAvFE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_azkiOi0o_sendMessage);
}

void Heavy_vSwellST::cMsg_Wqd0134y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_RNf6PZSA, 0, m, &hTable_RNf6PZSA_sendMessage);
}

void Heavy_vSwellST::cBinop_4RL06sBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yGtaZaED_sendMessage);
}

void Heavy_vSwellST::cMsg_hqgsdRhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_RNf6PZSA, 0, m, &hTable_RNf6PZSA_sendMessage);
}

void Heavy_vSwellST::cCast_azkiOi0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZYUoAvFE, 0, m, &cDelay_ZYUoAvFE_sendMessage);
}

void Heavy_vSwellST::cMsg_Nm7ie67G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_toPxRuD3, 2, m, &cDelay_toPxRuD3_sendMessage);
}

void Heavy_vSwellST::cTabhead_LtGWAPmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S0MeeFaZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_S0MeeFaZ_sendMessage);
}

void Heavy_vSwellST::cMsg_cecpMQvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6994irlP_sendMessage);
}

void Heavy_vSwellST::cSystem_6994irlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MEM4vih0_sendMessage);
}

void Heavy_vSwellST::cVar_4rXpdvgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P34tjNFp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_KidgGWvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KidgGWvQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjZ2LCq9, 0, m, &cDelay_sjZ2LCq9_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8dRWFNXL, 0, m, &sTabread_8dRWFNXL_sendMessage);
}

void Heavy_vSwellST::cDelay_sjZ2LCq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sjZ2LCq9, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8dRWFNXL, 0, m, &sTabread_8dRWFNXL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjZ2LCq9, 0, m, &cDelay_sjZ2LCq9_sendMessage);
}

void Heavy_vSwellST::sTabread_8dRWFNXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_pCapPv46, HV_BINOP_SUBTRACT, 0, m, &cBinop_pCapPv46_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_Q3urBTiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fq8OxnFE, HV_BINOP_MAX, 0, m, &cBinop_Fq8OxnFE_sendMessage);
}

void Heavy_vSwellST::cBinop_MEM4vih0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q3urBTiD, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q3urBTiD_sendMessage);
}

void Heavy_vSwellST::cBinop_S0MeeFaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gAxJ1Wvw_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8dRWFNXL, 0, m, &sTabread_8dRWFNXL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pOpkopzh_sendMessage);
}

void Heavy_vSwellST::cSystem_I1qKveQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCapPv46, HV_BINOP_SUBTRACT, 1, m, &cBinop_pCapPv46_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjZ2LCq9, 2, m, &cDelay_sjZ2LCq9_sendMessage);
}

void Heavy_vSwellST::cMsg_P34tjNFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I1qKveQy_sendMessage);
}

void Heavy_vSwellST::cMsg_gAxJ1Wvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KidgGWvQ, 0, m, &cDelay_KidgGWvQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjZ2LCq9, 0, m, &cDelay_sjZ2LCq9_sendMessage);
}

void Heavy_vSwellST::cMsg_JrvWVWl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fq8OxnFE, HV_BINOP_MAX, 1, m, &cBinop_Fq8OxnFE_sendMessage);
}

void Heavy_vSwellST::cBinop_Fq8OxnFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S0MeeFaZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_S0MeeFaZ_sendMessage);
}

void Heavy_vSwellST::cCast_pOpkopzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KidgGWvQ, 0, m, &cDelay_KidgGWvQ_sendMessage);
}

void Heavy_vSwellST::cBinop_Lr38Qezw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KidgGWvQ, 2, m, &cDelay_KidgGWvQ_sendMessage);
}

void Heavy_vSwellST::cBinop_pCapPv46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Lr38Qezw_sendMessage);
}

void Heavy_vSwellST::cCast_qr27i4Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4rXpdvgS, 0, m, &cVar_4rXpdvgS_sendMessage);
  cMsg_cecpMQvN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LtGWAPmE, 0, m, &cTabhead_LtGWAPmE_sendMessage);
}

void Heavy_vSwellST::cUnop_3OeeXPZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QYpOXIKg, m);
}

void Heavy_vSwellST::cCast_pwOFWbaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CCK1ypDk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RLMfWWtX, 0, m, &cVar_RLMfWWtX_sendMessage);
}

void Heavy_vSwellST::cCast_ASZJU4qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GfKQzOOc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_lzmhzZZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6DOALVgx, 0, m, &cVar_6DOALVgx_sendMessage);
}

void Heavy_vSwellST::cCast_pB6tPjUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TUiwt4w7, HV_BINOP_SUBTRACT, 0, m, &cBinop_TUiwt4w7_sendMessage);
}

void Heavy_vSwellST::cBinop_TUiwt4w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gIuH52Zp, 0, m, &cVar_gIuH52Zp_sendMessage);
}

void Heavy_vSwellST::cSend_CCK1ypDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L1Juep6Q_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_s8fqHjiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TaQP8hBV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_xfAXqOhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_kDdyT3rk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_oWWRNkqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KITMLmtA, 0, m, NULL);
}

void Heavy_vSwellST::cSend_xp63ntPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DvZeKCAo_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_28gJbhDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ik0pioAy, 1, m, &cDelay_Ik0pioAy_sendMessage);
}

void Heavy_vSwellST::cBinop_6nwWZ3sN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3OeeXPZO_sendMessage);
}

void Heavy_vSwellST::cReceive_TrTHHXxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TUiwt4w7, HV_BINOP_SUBTRACT, 1, m, &cBinop_TUiwt4w7_sendMessage);
}

void Heavy_vSwellST::cReceive_4IdyPtGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2kz5ucnq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2E9Oqwpv, 0, m, &cVar_2E9Oqwpv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4Sq692HK, 0, m, &cVar_4Sq692HK_sendMessage);
  cMsg_OstD2gML_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CF3mGQfa, 0, m, &cVar_CF3mGQfa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zLsoyZQy, 0, m, &cVar_zLsoyZQy_sendMessage);
  cMsg_foVyDfyt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UfFTooyd, 0, m, &cVar_UfFTooyd_sendMessage);
  cMsg_93TUbBPf_sendMessage(_c, 0, m);
  cMsg_NU8gzKJi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ys2BsSdr, 0, m, &cVar_Ys2BsSdr_sendMessage);
  cMsg_Val4y3BH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YGmhdjh1, 0, m, &cVar_YGmhdjh1_sendMessage);
  cMsg_MzYFITjt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sSiyvxfy, 0, m, &cTabhead_sSiyvxfy_sendMessage);
  cMsg_JrvWVWl1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4rXpdvgS, 0, m, &cVar_4rXpdvgS_sendMessage);
  cMsg_cecpMQvN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LtGWAPmE, 0, m, &cTabhead_LtGWAPmE_sendMessage);
}

void Heavy_vSwellST::cReceive_UoZ9baqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_ang1yS3e, 0, m, &cSlice_ang1yS3e_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_WLP1YsSK, 0, m, &cSlice_WLP1YsSK_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_5zYPswgG, 0, m, &cSlice_5zYPswgG_sendMessage);
}

void Heavy_vSwellST::cReceive_uzTbMO6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KryO01T1, m);
}

void Heavy_vSwellST::cReceive_L1Juep6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_15nF0fxj_sendMessage(_c, 0, m);
  cMsg_ZwizLXem_sendMessage(_c, 0, m);
  cMsg_8wAgsGoT_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_aNvCdjcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pwOFWbaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASZJU4qo_sendMessage);
}

void Heavy_vSwellST::cReceive_tFKf8iOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKS4IvzY, 1, m, &cVar_tKS4IvzY_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_0vV4elc9, 1, m, &cPack_0vV4elc9_sendMessage);
}

void Heavy_vSwellST::cReceive_2TmbmdR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0vV4elc9, 2, m, &cPack_0vV4elc9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cCDSr0sO, 1, m, &cDelay_cCDSr0sO_sendMessage);
}

void Heavy_vSwellST::cReceive_FngYTDKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_x41LckyF, 1, m, &cPack_x41LckyF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZKaHJGl2, 1, m, &cVar_ZKaHJGl2_sendMessage);
}

void Heavy_vSwellST::cReceive_ESFNhv8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_x41LckyF, 2, m, &cPack_x41LckyF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OF5OxHW5, 1, m, &cDelay_OF5OxHW5_sendMessage);
}

void Heavy_vSwellST::cReceive_bdEAkVbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wRxJrEty, 2, m, &cPack_wRxJrEty_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u3uAki1v, 1, m, &cDelay_u3uAki1v_sendMessage);
}

void Heavy_vSwellST::cReceive_DvZeKCAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ys2BsSdr, 1, m, &cVar_Ys2BsSdr_sendMessage);
  cMsg_xfAXqOhm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RLMfWWtX, 1, m, &cVar_RLMfWWtX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_u9LQBQeg, 1, m, &cVar_u9LQBQeg_sendMessage);
}

void Heavy_vSwellST::cReceive_KocnvcJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xp63ntPt_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_GGsysZWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_28gJbhDX_sendMessage);
}

void Heavy_vSwellST::cReceive_agicMr81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QdzwVIYZ, m);
}

void Heavy_vSwellST::cReceive_Jd8ZSBxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SpMMaleu, m);
}

void Heavy_vSwellST::cReceive_sIAVXUv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pB6tPjUQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lzmhzZZV_sendMessage);
}

void Heavy_vSwellST::cReceive_HEsyLLjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6nwWZ3sN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RmIQ1epe, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_0LNC8DPs, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_EWG1og67, VIf(I1));
    __hv_varread_f(&sVarf_QdzwVIYZ, VOf(Bf0));
    __hv_varread_f(&sVarf_SpMMaleu, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_MD5A8yBg, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_xGh3uZdH, VOf(Bf1));
    __hv_rpole_f(&sRPole_BlUHULlb, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_RmIQ1epe, VOf(Bf0));
    __hv_varread_f(&sVarf_QYpOXIKg, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_LTjp6YAn, VIf(Bf2), &sEnv_LTjp6YAn_sendMessage);
    __hv_tabread_f(&sTabread_aOdpk9kg, VOf(Bf2));
    __hv_line_f(&sLine_KITMLmtA, VOf(Bf0));
    __hv_varread_f(&sVarf_KryO01T1, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_t0iNg1BW, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_tabread_f(&sTabread_8dRWFNXL, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed
}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
