/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvSignalLine.h"
#include "HvTable.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvSignalDel1.h"
#include "HvControlIf.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvControlTabhead.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_LTjp6YAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ga4cN8YX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XJQOGN2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_1d5yNqep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n7lkLbse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_liISiFBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C3ja6VfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vMNayvPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XBVaIxv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PhY1itCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7RJqmOoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sWHLB7yU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XPekIGRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_tQ3q2Lur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z6u7Pvbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ajn3S4yd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4p4IGshu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xR9zgtk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H33gbnMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bf6zeyzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wBTSVJ6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_O54NEOtn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ni6iFSAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2r4fNRLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_afBYRFsn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_44xHJ4HQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1j5RLm1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6DOALVgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gIuH52Zp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fXeCsSgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I3LeJfzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u7nHVYUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6alWrZhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ang1yS3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_WLP1YsSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_5zYPswgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4Sq692HK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hkRjRjfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WCwa9Uh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K6ATMhCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GT8hf5pN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jtB1zC8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8lFfmjG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QSqmJVlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xVSX5LZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_byhe2s4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_le9sQ0i8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTXcdFqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_70dcWC4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8E2pxrug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OcJSHaCo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sAEBBJmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IxPO7yIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zdRot9na_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_cCDSr0sO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KAD7Mxz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w3Rdyizq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_0vV4elc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u9LQBQeg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_15nF0fxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LJKYFsVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DA3Sbekb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Em1647Qh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QzP6hpJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zRoKL00a_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_OF5OxHW5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B8s2mzsU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2B7CJlRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_x41LckyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tKS4IvzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZwizLXem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ypKSu23W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gFnKTD3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RB6Rp0TV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ByfrajwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5Xof9dOC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_u3uAki1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ggnc0JM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6bw81vP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_wRxJrEty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZKaHJGl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8wAgsGoT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5WwcbU3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vJwrlHfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tnM0Dd7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xuAFXr5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TaQP8hBV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_4kRHhK2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RLMfWWtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ys2BsSdr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OstD2gML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PRHSwPVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MkCKhQTF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RDiqbbma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AzAInbBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2kz5ucnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ru5xAIZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2E9Oqwpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FbmNDjq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JImPSoYw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YNZErRI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hvx1ZBb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z5WEn3JK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oMDLlw8E_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_4Qqu4be2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3niOLePp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kDdyT3rk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xXsZoTYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_hmYZIBuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LJfdkluu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zLsoyZQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_niWEhOng_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_g7tCcVXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CF3mGQfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IL2m0JaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RH1pYNDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_iVxGsVud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_SgAmmAQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m8i9OsFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3h4ke7ZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sStZK1mH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Ox5s7CP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EfNxXRtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4D52VndU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sVhVYa67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5yIm9lpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GNi97YHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_16mQIwDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fh9Dvhpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dlXMbXq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2nV0go2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AJ2qBmRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9rcckUDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YWbFpv0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kE9yrWhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OW4OUYkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JIq2Ne4d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F8GqdXQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FQm2YnXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WV6MJK3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jzPmgkLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JN1o9r8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ypWRASg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U6nVMLo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4kKZx0EM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VHxxqLow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GfKQzOOc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ik0pioAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AjvpawCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1YSehE8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UfFTooyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_foVyDfyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xF72kAsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKOSluOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hafx5hJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zXrqKOoK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHDvk4y0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K5uWkRSB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exNnzJQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_93TUbBPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OaACDTBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hkVnDLo8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q6lCC2LL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BXLTf942_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ELCoSslG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r1LiD5bN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5JHF5jqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_os9ccqKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OCfVJBGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t3TUZKoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_sSiyvxfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MzYFITjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_temBoxRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YGmhdjh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q4P8u8eS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GlpYsAA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_aOdpk9kg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GxKn0K4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QpkdZ5aO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xiJoX6sL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YM1gg9Dm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSf3ZFZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JjNJrQHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Val4y3BH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BvHwU6EW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WqTqBBk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yy5gUnZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fAckA7rW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FzyofK2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NU8gzKJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_p8ExBr7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZYUoAvFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_toPxRuD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yGtaZaED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_RNf6PZSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wqd0134y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4RL06sBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hqgsdRhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_azkiOi0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nm7ie67G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_LtGWAPmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cecpMQvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6994irlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4rXpdvgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KidgGWvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sjZ2LCq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_8dRWFNXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q3urBTiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MEM4vih0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S0MeeFaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I1qKveQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P34tjNFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gAxJ1Wvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JrvWVWl1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fq8OxnFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pOpkopzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lr38Qezw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pCapPv46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qr27i4Nm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3OeeXPZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pwOFWbaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ASZJU4qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lzmhzZZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pB6tPjUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TUiwt4w7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CCK1ypDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s8fqHjiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xfAXqOhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWWRNkqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xp63ntPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_28gJbhDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6nwWZ3sN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TrTHHXxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4IdyPtGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UoZ9baqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uzTbMO6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_L1Juep6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aNvCdjcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tFKf8iOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2TmbmdR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FngYTDKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ESFNhv8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bdEAkVbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DvZeKCAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KocnvcJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GGsysZWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_agicMr81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jd8ZSBxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sIAVXUv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HEsyLLjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_0LNC8DPs;
  SignalTabwrite sTabwrite_EWG1og67;
  SignalRPole sRPole_BlUHULlb;
  SignalEnvelope sEnv_LTjp6YAn;
  SignalTabread sTabread_aOdpk9kg;
  SignalLine sLine_KITMLmtA;
  SignalTabread sTabread_8dRWFNXL;
  ControlSlice cSlice_XJQOGN2h;
  ControlSlice cSlice_1d5yNqep;
  ControlVar cVar_n7lkLbse;
  ControlIf cIf_liISiFBJ;
  ControlBinop cBinop_XBVaIxv3;
  ControlSlice cSlice_XPekIGRW;
  ControlSlice cSlice_tQ3q2Lur;
  ControlVar cVar_z6u7Pvbx;
  ControlIf cIf_ajn3S4yd;
  ControlBinop cBinop_H33gbnMN;
  ControlVar cVar_6DOALVgx;
  ControlVar cVar_gIuH52Zp;
  ControlBinop cBinop_fXeCsSgK;
  ControlBinop cBinop_I3LeJfzG;
  ControlSlice cSlice_ang1yS3e;
  ControlSlice cSlice_WLP1YsSK;
  ControlSlice cSlice_5zYPswgG;
  ControlVar cVar_4Sq692HK;
  ControlIf cIf_K6ATMhCe;
  ControlBinop cBinop_GT8hf5pN;
  ControlIf cIf_jtB1zC8q;
  ControlIf cIf_8lFfmjG0;
  ControlIf cIf_QSqmJVlp;
  ControlIf cIf_xVSX5LZO;
  ControlBinop cBinop_byhe2s4q;
  ControlBinop cBinop_le9sQ0i8;
  ControlBinop cBinop_MTXcdFqr;
  ControlBinop cBinop_IxPO7yIm;
  ControlDelay cDelay_cCDSr0sO;
  ControlPack cPack_0vV4elc9;
  ControlVar cVar_u9LQBQeg;
  ControlDelay cDelay_OF5OxHW5;
  ControlPack cPack_x41LckyF;
  ControlVar cVar_tKS4IvzY;
  ControlDelay cDelay_u3uAki1v;
  ControlPack cPack_wRxJrEty;
  ControlVar cVar_ZKaHJGl2;
  ControlVar cVar_RLMfWWtX;
  ControlVar cVar_Ys2BsSdr;
  SignalVarf sVarf_t0iNg1BW;
  ControlDelay cDelay_RDiqbbma;
  ControlVar cVar_2E9Oqwpv;
  ControlBinop cBinop_JImPSoYw;
  ControlBinop cBinop_YNZErRI2;
  ControlBinop cBinop_Hvx1ZBb9;
  ControlVar cVar_Z5WEn3JK;
  ControlSlice cSlice_xXsZoTYG;
  ControlSlice cSlice_hmYZIBuo;
  ControlVar cVar_LJfdkluu;
  ControlVar cVar_zLsoyZQy;
  ControlVar cVar_CF3mGQfa;
  ControlVar cVar_IL2m0JaI;
  ControlVar cVar_RH1pYNDC;
  ControlSlice cSlice_iVxGsVud;
  ControlSlice cSlice_SgAmmAQO;
  ControlBinop cBinop_m8i9OsFs;
  ControlBinop cBinop_3h4ke7ZP;
  ControlBinop cBinop_sStZK1mH;
  ControlBinop cBinop_3Ox5s7CP;
  ControlBinop cBinop_EfNxXRtz;
  ControlBinop cBinop_5yIm9lpZ;
  ControlBinop cBinop_GNi97YHM;
  ControlBinop cBinop_16mQIwDz;
  ControlBinop cBinop_Fh9Dvhpv;
  ControlBinop cBinop_OW4OUYkG;
  ControlBinop cBinop_JN1o9r8O;
  ControlDelay cDelay_Ik0pioAy;
  ControlVar cVar_UfFTooyd;
  ControlBinop cBinop_GKOSluOW;
  ControlBinop cBinop_hafx5hJp;
  SignalVarf sVarf_xGh3uZdH;
  ControlBinop cBinop_OHDvk4y0;
  ControlBinop cBinop_K5uWkRSB;
  ControlBinop cBinop_exNnzJQU;
  SignalVarf sVarf_MD5A8yBg;
  ControlDelay cDelay_hkVnDLo8;
  ControlDelay cDelay_Q6lCC2LL;
  ControlBinop cBinop_BXLTf942;
  HvTable hTable_ELCoSslG;
  ControlBinop cBinop_5JHF5jqv;
  ControlTabhead cTabhead_sSiyvxfy;
  ControlVar cVar_YGmhdjh1;
  ControlDelay cDelay_Q4P8u8eS;
  ControlDelay cDelay_GlpYsAA5;
  ControlBinop cBinop_GxKn0K4b;
  ControlBinop cBinop_QpkdZ5aO;
  ControlBinop cBinop_xiJoX6sL;
  ControlBinop cBinop_BvHwU6EW;
  ControlBinop cBinop_yy5gUnZA;
  ControlBinop cBinop_fAckA7rW;
  ControlDelay cDelay_ZYUoAvFE;
  ControlDelay cDelay_toPxRuD3;
  ControlBinop cBinop_yGtaZaED;
  HvTable hTable_RNf6PZSA;
  ControlBinop cBinop_4RL06sBl;
  ControlTabhead cTabhead_LtGWAPmE;
  ControlVar cVar_4rXpdvgS;
  ControlDelay cDelay_KidgGWvQ;
  ControlDelay cDelay_sjZ2LCq9;
  ControlBinop cBinop_Q3urBTiD;
  ControlBinop cBinop_MEM4vih0;
  ControlBinop cBinop_S0MeeFaZ;
  ControlBinop cBinop_Fq8OxnFE;
  ControlBinop cBinop_Lr38Qezw;
  ControlBinop cBinop_pCapPv46;
  ControlBinop cBinop_TUiwt4w7;
  ControlBinop cBinop_s8fqHjiL;
  ControlBinop cBinop_28gJbhDX;
  ControlBinop cBinop_6nwWZ3sN;
  SignalVarf sVarf_KryO01T1;
  SignalVarf sVarf_QdzwVIYZ;
  SignalVarf sVarf_SpMMaleu;
  SignalVarf sVarf_QYpOXIKg;
  SignalVarf sVarf_RmIQ1epe;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
